package cn.com.qmth.examcloud.exchange;

import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.cloud.netflix.eureka.EnableEurekaClient;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;

import cn.com.qmth.examcloud.exchange.inner.service.upyun.UpyunSiteManager;
import cn.com.qmth.examcloud.web.bootstrap.AppBootstrap;

/**
 * Exchange不连接除Redis外的任何数据库. 说明 by wangwei.<br>
 * 
 * inner 提供云平台向南调用的中间件<br>
 * outer 提供第三方接入的中间件<br>
 *
 */

@SpringBootApplication
@Configuration
@EnableEurekaClient
@EnableDiscoveryClient
@ComponentScan(basePackages = {"cn.com.qmth"})
@EnableAutoConfiguration(exclude = {DataSourceAutoConfiguration.class})
public class ExchangeApp {

	static {
		String runtimeLevel = System.getProperty("log.commonLevel");
		if (null == runtimeLevel) {
			System.setProperty("log.commonLevel", "DEBUG");
		}
		System.setProperty("hibernate.dialect.storage_engine", "innodb");
	}

	/**
	 * main
	 *
	 * @author WANGWEI
	 * @param args
	 */
	public static void main(String[] args) {
		AppBootstrap.run(ExchangeApp.class, args);

		UpyunSiteManager.init();
	}
}